# `BioClients.dnorm`

## DNorm

NCBI CBB REST client (Computational Biology Branch)

* <https://www.ncbi.nlm.nih.gov/CBBresearch/Lu/Demo/RESTful/tmTool.cgi>
* <https://www.ncbi.nlm.nih.gov/CBBresearch/Lu/Demo/RESTful/tmTool.cgi/Disease/19894120/JSON>
